"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const Listr = require("listr");
const get_java_version_1 = require("../utils/get-java-version");
const download_tools_1 = require("./download-tools");
const MIN_NODE_VERSION = 14;
const MIN_JAVA_VERSION = 8;
function checkPrerequisites(options) {
    return new Listr([
        {
            title: 'Checking Node.js version',
            task: () => {
                const majorVersion = parseInt(process.versions.node.split('.')[0]);
                if (majorVersion < MIN_NODE_VERSION)
                    throw new VersionError('Node.js', MIN_NODE_VERSION, majorVersion);
            },
        },
        {
            title: 'Checking Java version',
            task: async () => {
                const majorVersion = await get_java_version_1.default();
                if (majorVersion < MIN_JAVA_VERSION)
                    throw new VersionError('Java', MIN_JAVA_VERSION, majorVersion);
            },
        },
        {
            title: 'Downloading tools',
            task: () => download_tools_1.default(options),
        },
    ]);
}
exports.default = checkPrerequisites;
class VersionError extends Error {
    constructor(tool, minVersion, currentVersion) {
        super(`apk-mitm requires at least ${tool} ${minVersion} to work and you seem to be using ${tool} ${currentVersion}.` +
            ` Please upgrade your ${tool} installation and try again!`);
        this.name = VersionError.name;
    }
}
